addpath eigopt/
addpath GRANSO/
addpath COMPlib_r1_1/ 
addpath testexamples/



options.print = 1;
options.gamma = -400;




fprintf('*********\n');
fprintf('** Optimizing epsilon-pseudospectral abscissa for NN18\n');
fprintf('** epsilon=0.2, box = [-1,1]\n');
fprintf('*********\n');

[A,~,B,~,C,~,~,~,~,~,~,~,~] = COMPleib('NN18');
sys.A = cell(1,2); 
sys.A{1} = A;
sys.A{2} = B*C; 
sys.f = @(x)[1 x]; 
bounds.lb = -1; 
bounds.ub = 1;
[Rz,mu,~] = PSA_subspace_framework(sys,0.2,bounds,options);

fprintf('*********\n');
fprintf('Optimal pseudospectral abscissa: %.7f\n', Rz);
fprintf('Optimizing mu: %.5f\n',mu);
pause(2);







fprintf('\n');
fprintf('\n');
fprintf('*********\n');
fprintf('** Optimizing epsilon-pseudospectral abscissa for HF1\n');
fprintf('** epsilon=0.2, box = [-1,1]x[-1,1]\n');
fprintf('*********\n');

[A,~,B,~,C,~,~,~,~,~,~,~,~] = COMPleib('HF1');
sys.A = cell(1,3);
sys.A{1} = A;
sys.A{2} = B*C(1,:);
sys.A{3} = B*C(2,:);
sys.f = @(x)[1 x(1) x(2)]; 
bounds.lb = [-1; -1];
bounds.ub = [1; 1];
[Rz,mu,~] = PSA_subspace_framework(sys,0.2,bounds,options);

fprintf('*********\n');
fprintf('Optimal pseudospectral abscissa: %.7f\n', Rz);
for j = 1:2
    fprintf('Optimizing mu(%d): %.5f\n',j,mu(j));
end
pause(2);






fprintf('\n');
fprintf('\n');
fprintf('*********\n');
fprintf('** Optimizing epsilon-pseudospectral abscissa for HF2D2\n');
fprintf('** epsilon=0.2, box = [-1,1]^6\n');
fprintf('*********\n');

[A,~,B,~,C,~,~,~,~,~,~,~,~] = COMPleib('HF2D2');
sys.A = cell(1,7);
sys.A{1} = A;
sys.A{2} = B(:,1)*C(1,:);
sys.A{3} = B(:,1)*C(2,:);
sys.A{4} = B(:,1)*C(3,:);
sys.A{5} = B(:,2)*C(1,:);
sys.A{6} = B(:,2)*C(2,:);
sys.A{7} = B(:,2)*C(3,:);
sys.f = @(x)[1 x(1) x(2) x(3) x(4) x(5) x(6)]; 
bounds.lb = [-1; -1; -1; -1; -1; -1];
bounds.ub = [1; 1; 1; 1; 1; 1];

[Rz,mu,~] = PSA_subspace_framework(sys,0.2,bounds,options);

fprintf('*********\n');
fprintf('Optimal pseudospectral abscissa: %.7f\n', Rz);
for j = 1:6
    fprintf('Optimizing mu(%d): %.5f\n',j,mu(j));
end





rmpath eigopt/
rmpath GRANSO/
rmpath COMPlib_r1_1/ 
rmpath testexamples/

