function [z, x, succ] = get_rightmost_eigvec(A, scalefac, u, v, A_sparse,k)
% Compute the right-most eigenvalue (z) and right eigenvector (x)
% of B = A + scalefac*u*v'

% Modified from PSAPSR

n = length(u); 
opts.tol = 10^-8;
opts.maxit = 500;
opts.p = 30;

%%% Compute right-most eigenvalue of A+scalefac*u*v'
if ~A_sparse % A is dense, so compute all the eigenvalues
    B = A + scalefac*u*v';
    [X, Lambda] = eig(B);
    lambda = diag(Lambda);

    succ = 1;
    
    % sort eigenvalues
    [lamsort, indx] = sortcomplex(lambda, 0);
    z = lamsort(1); % same as lambda(indx(k))
    x = X(:,indx(1)); % corresponding eigenvector

else % sparse  
    opts.disp = 0; % for eigs
    
    if (sum(u == 0) ~= n)
        opts.isreal = isreal(A) & isreal(scalefac) & isreal(u) & isreal(v); 
        eigscode = 'largestreal'; % want eigenvalue(s) with largest real parts

        
        Afun = @(p)aplusuvt(A, 2, scalefac, u, v, 0, p);
        if norm(v,1) > 0 
            opts.v0 = v;  
        end

        
        [X, lambda] = eigs(Afun, n, 1, eigscode, opts);    
        % EIGS failed. Try with a larger subspace.
        if isempty(lambda) || isnan(lambda)
            fprintf('subspace iteration # %d\n',k);
            warning('Taking larger subspace for EIGS.')
            extra = 10;       
            [X, lambda] = eigs(Afun, n, extra, eigscode, opts); 
        end
        
        if isempty(lambda)
            warning('geteigvecs: eigs found no eigenvalues to default accuracy. Exiting.')
            succ = 0;
            z = []; x = [];
            return
        else
            succ = 1;   
            
            [lamsort, indx] = sortcomplex(lambda, 0);
            z = lamsort(1); 
            x = X(:,indx(1));
        end    
    else
        [vt1,zt1] = eigs(A,1,'smallestabs',opts);
        [vt2,zt2] = eigs(A,1,'largestabs',opts);
        
        if (real(zt1) > real(zt2))
            z = zt1;
            x = vt1;
        else
            z = zt2;
            x = vt2;
        end
        
        succ = 1;
    end
end


